function F = amplavi

a=[10:1:19  20:2:38  40:5:95];
f=1000*[a/10 a 10*a 100*a 1e4];
logf = log10(f);

cap = 1e-11;              % 10 pF
rb = 1000;                % 1 kOhm
rbe = 1000;               % 1 kOhm
rc = 1000;                % 1 kOhm
g1 = 1/rb; 
g2 = 1/rbe; 
g3 = 1i*2*pi*f*cap;
g4 = 1/rc;
b = 300;                  % Stromverstaerkung

ampl=-g1*(g2*b-g3)./(g1*g3+g1*g4+g2*g3*(1+b)+g2*g4+g3*g4);

dezibel = 20*log10(abs(ampl));
phase = 180/pi*atan2(imag(ampl), real(ampl));

ampl = ampl/max(abs(ampl));

fig = imread('amp.png', 'png');
totalx = 576;
totaly = 432;
figx = size(fig, 2);
figy = size(fig, 1);
figw = figx/totalx;
figh = figy/totaly;

for n=1:size(f,2)
    subplot('position', [0.1 0.55 figw figh]);
    image(fig); axis off;
    ht = title('Emitterschaltung: Frequenzgang');
    set(ht, 'position', [0 -10], 'FontSize', 12, 'FontWeight', 'bold',...
        'HorizontalAlignment', 'left', 'VerticalAlignment', 'bottom');
    
    subplot(2,2,3);
    T=10^(-round(logf(n)));
    t=linspace(0, 10*T, 300);
    y1 = cos(2*pi*f(n)*t)+1i*sin(2*pi*f(n)*t);
    y2 = ampl(n)*y1;
    plot(t, real(y1), 'b-', t, real(y2), 'r-');
    axis([0 10*T -1.2 1.2]);
    legend('Ue', 'Ua');
    xlabel('Zeit [s]');
    t = sprintf('Frequenz: %8d Hz', f(n));
    ht = text(0, 1.6, t);
    set(ht, 'FontSize', 12, 'FontWeight', 'bold');
    
    subplot(2,2,2);
    hp=plot(logf, dezibel, logf(n), dezibel(n), 'ro');
    set(hp(2), 'LineWidth', 2);
    axis([3 7 0 45]);
    xlabel('log(Frequenz/Hz)');
    ylabel('Verstrkung [db]');
    
    subplot(2,2,4);
    hp=plot(logf, phase, logf(n), phase(n), 'ro');
    set(hp(2), 'LineWidth', 2);
    axis([3 7 85 185]);
    xlabel('log(Frequenz/Hz)');
    ylabel('Phase [grad]');
    set(gcf,'Color','w');
    
    F(n) = getframe(gcf);
end

if nargout==0,
    movie2avi(F, 'ampl.avi', 'fps', 5, 'quality', 90, 'keyframe', 0.5);
end;

end

